@@ -1,7 +1,5 @@
-// Copyright (C) 2009 NICTA
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2009-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2009-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -20,42 +18,44 @@
 
 template<typename T1>
 inline
-bool
-chol(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& X)
+const Op<T1, op_chol>
+chol
+  (
+  const Base<typename T1::elem_type,T1>& X,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
-  typedef typename T1::elem_type eT;
-  
-  const unwrap_check<T1> tmp(X.get_ref(), out);
-  const Mat<eT>&     A = tmp.M;
-  
-  arma_debug_check( (A.is_square() == false), "chol(): given matrix is not square");
-  
-  return auxlib::chol(out, A);
+  return Op<T1, op_chol>(X.get_ref());
   }
 
 
 
 template<typename T1>
 inline
-Mat<typename T1::elem_type>
-chol(const Base<typename T1::elem_type,T1>& X)
+bool
+chol
+  (
+         Mat<typename T1::elem_type>&    out,
+  const Base<typename T1::elem_type,T1>& X,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
-  typedef typename T1::elem_type eT;
-  
-  Mat<eT> out;
-  
-  const bool ok = chol(out, X);
-  
-  if(ok == false)
+  try
     {
-    arma_print("chol(): matrix factorisation failed");
+    out = chol(X);
+    }
+  catch(std::runtime_error&)
+    {
+    return false;
     }
   
-  return out;
+  return true;
   }
 
 
